@@ -466,6 +466,76 @@ def interactive_dqdv(file_name):
     s_dqdv.on_changed(update)
     plt.show()
     return()
+def cycling_CCCV_st(file_name,cycle_num):
+    '''
+    This function helps the user plot the battery cycling data for the visualization
+
+    Parameters
+    ----------
+
+    file_name : str
+        file name of the file to be read. Should be the battery cycling data.
+    cycle_num : in
+        battery cycle number.
+
+    Returns
+    -------
+    fig : figure
+        Plot of charge discharge curve.
+    '''
+ 
+    
+    
+    df=pd.read_csv(file_name)
+    charge=cycling_data_processing(df,cycle_num,'charge');
+    discharge=cycling_data_processing(df,cycle_num,'discharge');
+        
+    cycle_fig = figure(title='', x_axis_label='Capacity(Ah)', y_axis_label='Voltage(V)')
+    cycle_fig.line(charge['Capacity(Ah)'],charge['Voltage(V)'], legend_label='charge', line_width=2)
+    cycle_fig.line(discharge['Capacity(Ah)'],discharge['Voltage(V)'], legend_label='discharge', color="orange", line_width=2)
+
+    fig = st.bokeh_chart(cycle_fig)
+    return (fig)
+
+def diff_cap_st(file_name,cycle_num):
+    '''
+    
+
+     This function helps the user plot the differential capacity data for the visualization
+
+     Parameters
+     ----------
+     file_name : str
+         file name of the file to be read. Should be the battery cycling data.
+     cycle_num : in
+         battery cycle number.
+
+     Returns
+     -------
+     fig : figure
+        Plot of differential capacity curve.
+     '''
+     
+    df=pd.read_csv(file_name)
+    charge=cycling_data_processing(df,cycle_num,'charge')
+    discharge=cycling_data_processing(df,cycle_num,'discharge')
+    charge_V=charge['Voltage(V)'][(charge['Voltage(V)']<4.18)]
+    charge_cap=charge['Capacity(Ah)'][(charge['Voltage(V)']<4.18)]
+    discharge_V=discharge['Voltage(V)'][(discharge['Voltage(V)']<4.18)]
+    discharge_cap=discharge['Capacity(Ah)'][(discharge['Voltage(V)']<4.18)]
+    
+    dqdv_charge=np.diff(charge_cap)/np.diff(charge_V)
+
+    N_charge=len(dqdv_charge)
+    dqdv_discharge=np.diff(discharge_cap)/np.diff(discharge_V)
+    N_discharge=len(dqdv_discharge)
+    
+    dqdv_fig = figure(title='', x_axis_label='Voltage(V)', y_axis_label='dQ/dV')
+    dqdv_fig.line(charge_V[0:N_charge], dqdv_charge, legend_label='charge', line_width=2)
+    dqdv_fig.line(discharge_V[0:N_discharge],dqdv_discharge, legend_label='discharge', color="orange", line_width=2)
+
+    fig = st.bokeh_chart(dqdv_fig)
+    return (fig)
 
 
     
